==> scala-swing_2.12-2.0.3-sources.jar: scala/swing/Reactions.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2007-2013, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |    http://scala-lang.org/               **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */



package scala.swing

import scala.collection.mutable
import scala.collection.mutable.ListBuffer
import scala.swing.event.Event

object Reactions {
  class Impl extends Reactions {
    private val parts: mutable.Buffer[Reaction] = new ListBuffer[Reaction]
    def isDefinedAt(e: Event): Boolean = parts.exists(_ isDefinedAt e)
    def += (r: Reaction): this.type = { parts += r; this }
    def -= (r: Reaction): this.type = { parts -= r; this }
    def apply(e: Event): Unit = {
      for (p <- parts) if (p isDefinedAt e) p(e)
    }
  }

  type Reaction = PartialFunction[Event, Unit]

  /**
   * A Reaction implementing this trait is strongly referenced in the reaction list
   */
  trait StronglyReferenced

  class Wrapper(listener: Any)(r: Reaction) extends Reaction with StronglyReferenced with Proxy {
    def self: Any = listener
    def isDefinedAt(e: Event): Boolean = r.isDefinedAt(e)
    def apply(e: Event): Unit = r(e)
  }
}

/**
 * Used by reactors to let clients register custom event reactions.
 */
abstract class Reactions extends Reactions.Reaction {
  /**
   * Add a reaction.
   */
  def += (r: Reactions.Reaction): this.type

  /**
   * Remove the given reaction.
   */
  def -= (r: Reactions.Reaction): this.type
}

==> scala-swing_2.12-2.1.0-sources.jar: scala/swing/Reactions.scala <==
/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2007-2013, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |    http://scala-lang.org/               **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

package scala.swing

import scala.collection.mutable
import scala.swing.event.Event

object Reactions {
  class Impl extends Reactions {
    private val parts: mutable.Buffer[Reaction] = new mutable.ListBuffer[Reaction]
    def isDefinedAt(e: Event): Boolean = parts.exists(_ isDefinedAt e)
    def += (r: Reaction): this.type = { parts += r; this }
    def -= (r: Reaction): this.type = { parts -= r; this }
    def apply(e: Event): Unit = {
      for (p <- parts) if (p isDefinedAt e) p(e)
    }
  }

  type Reaction = PartialFunction[Event, Unit]

  /**
   * A Reaction implementing this trait is strongly referenced in the reaction list
   */
  trait StronglyReferenced

  class Wrapper(listener: Any)(r: Reaction) extends Reaction with StronglyReferenced with Proxy {
    def self: Any = listener
    def isDefinedAt(e: Event): Boolean = r.isDefinedAt(e)
    def apply(e: Event): Unit = r(e)
  }
}

/**
 * Used by reactors to let clients register custom event reactions.
 */
abstract class Reactions extends Reactions.Reaction {
  /**
   * Add a reaction.
   */
  def += (r: Reactions.Reaction): this.type

  /**
   * Remove the given reaction.
   */
  def -= (r: Reactions.Reaction): this.type
}
